@@ -3,18 +3,23 @@ Created on 2022-09-12
 
 @author: wf
 '''
+import typing
+
 from addict import Dict
 import asyncio
 import inspect
 from types import MethodType
 
+from starlette.websockets import WebSocket
+
+
 class WebPage:
     """
     a web page
     """ 
     # TODO: Add page events online, beforeunload, resize
-    instances = {}
-    sockets = {}
+    instances: typing.Dict[int, 'WebPage'] = {}
+    sockets: typing.Dict[int, typing.Dict[int, WebSocket]] = {}
     next_page_id = 0
     use_websockets = True
     delete_flag = True
@@ -271,8 +276,18 @@ class WebPage:
             raise Exception(f"No event of type {event_type} supported")
 
     async def run_event_function(
-        self, event_type, event_data, create_namespace_flag=True
+            self,
+            event_type: str,
+            event_data: dict,
+            create_namespace_flag: bool = True
     ):
+        """
+        Run event_function with the given event_data
+        Args:
+            event_type: type of the event e.g. 'before', "after", 'click, 'change', ...
+            event_data: data sent along with the event
+            create_namespace_flag: If True convert event_data to Dict object
+        """
         event_function = getattr(self, "on_" + event_type)
         if create_namespace_flag:
             function_data = Dict(event_data)
